/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.hadoop.codec;

import io.airlift.compress.lz4.Lz4Decompressor;
import java.io.IOException;
import java.nio.ByteBuffer;
import org.apache.hadoop.io.compress.DirectDecompressor;

public class Lz4RawDecompressor extends NonBlockedDecompressor implements DirectDecompressor {

  private Lz4Decompressor decompressor = new Lz4Decompressor();

  @Override
  protected int maxUncompressedLength(ByteBuffer compressed, int maxUncompressedLength) throws IOException {
    // We cannot obtain the precise uncompressed length from the input data.
    // Simply return the maxUncompressedLength.
    return maxUncompressedLength;
  }

  @Override
  protected int uncompress(ByteBuffer compressed, ByteBuffer uncompressed) throws IOException {
    decompressor.decompress(compressed, uncompressed);
    int uncompressedSize = uncompressed.position();
    uncompressed.limit(uncompressedSize);
    uncompressed.rewind();
    return uncompressedSize;
  }

  @Override
  public void decompress(ByteBuffer compressed, ByteBuffer uncompressed) throws IOException {
    uncompress(compressed, uncompressed);
  }
}
