/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.thrift.projection.deprecated;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * Test using glob syntax to specify which attribute to retain
 */
public class PathGlobPatternTest {
  @Test
  public void testRecursiveGlob() {
    PathGlobPattern g = new PathGlobPattern("a/**/b");
    assertFalse(g.matches("a/b"));
    assertTrue(g.matches("a/asd/b"));
    assertTrue(g.matches("a/asd/ss/b"));

    g = new PathGlobPattern("a/**");
    assertTrue(g.matches("a/as"));
    assertTrue(g.matches("a/asd/b"));
    assertTrue(g.matches("a/asd/ss/b"));
  }

  @Test
  public void testStandardGlob() {
    PathGlobPattern g = new PathGlobPattern("a/*");
    assertTrue(g.matches("a/as"));
    assertFalse(g.matches("a/asd/b"));
    assertFalse(g.matches("a/asd/ss/b"));

    g = new PathGlobPattern("a/{bb,cc}/d");
    assertTrue(g.matches("a/bb/d"));
    assertTrue(g.matches("a/cc/d"));
    assertFalse(g.matches("a/cc/bb/d"));
    assertFalse(g.matches("a/d"));
  }
}
